# Updating User Permissions
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/updating-user-permissions#overview)
  * [Prerequisites](https://help.sap.com/docs/leanix/ea/updating-user-permissions#prerequisites)
  * [Step 1: Retrieve User Permissions](https://help.sap.com/docs/leanix/ea/updating-user-permissions#step-1:-retrieve-user-permissions)
  * [Step 2: Update User Permissions](https://help.sap.com/docs/leanix/ea/updating-user-permissions#step-2:-update-user-permissions)


Update user permissions through the MTM REST API.
